==> config-api-0.3.8-sources.jar: org/wildfly/swarm/config/messaging_activemq/server/RemoteAcceptor.java <==
package org.wildfly.swarm.config.messaging_activemq.server;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.Map;
/**
 * Defines a way in which remote connections can be made to the ActiveMQ server.
 */
@ResourceType("remote-acceptor")
public class RemoteAcceptor {

	private String key;
	private Map params;
	private String socketBinding;
	private Boolean started;

	public RemoteAcceptor(String key) {
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * A key-value pair understood by the acceptor factory-class and used to configure it.
	 */
	@ModelNodeBinding(detypedName = "params")
	public Map params() {
		return this.params;
	}

	/**
	 * A key-value pair understood by the acceptor factory-class and used to configure it.
	 */
	@SuppressWarnings("unchecked")
	public RemoteAcceptor params(Map value) {
		this.params = value;
		return (RemoteAcceptor) this;
	}

	/**
	 * The socket binding that the acceptor will use to accept connections.
	 */
	@ModelNodeBinding(detypedName = "socket-binding")
	public String socketBinding() {
		return this.socketBinding;
	}

	/**
	 * The socket binding that the acceptor will use to accept connections.
	 */
	@SuppressWarnings("unchecked")
	public RemoteAcceptor socketBinding(String value) {
		this.socketBinding = value;
		return (RemoteAcceptor) this;
	}

	/**
	 * Whether this acceptor is started.
	 */
	@ModelNodeBinding(detypedName = "started")
	public Boolean started() {
		return this.started;
	}

	/**
	 * Whether this acceptor is started.
	 */
	@SuppressWarnings("unchecked")
	public RemoteAcceptor started(Boolean value) {
		this.started = value;
		return (RemoteAcceptor) this;
	}
}

==> config-api-0.3.10-sources.jar: org/wildfly/swarm/config/messaging_activemq/server/RemoteAcceptor.java <==
package org.wildfly.swarm.config.messaging_activemq.server;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.Map;
/**
 * Defines a way in which remote connections can be made to the ActiveMQ server.
 */
@ResourceType("remote-acceptor")
public class RemoteAcceptor<T extends RemoteAcceptor> {

	private String key;
	private Map params;
	private String socketBinding;
	private Boolean started;

	public RemoteAcceptor(String key) {
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * A key-value pair understood by the acceptor factory-class and used to configure it.
	 */
	@ModelNodeBinding(detypedName = "params")
	public Map params() {
		return this.params;
	}

	/**
	 * A key-value pair understood by the acceptor factory-class and used to configure it.
	 */
	@SuppressWarnings("unchecked")
	public RemoteAcceptor params(Map value) {
		this.params = value;
		return (RemoteAcceptor) this;
	}

	/**
	 * The socket binding that the acceptor will use to accept connections.
	 */
	@ModelNodeBinding(detypedName = "socket-binding")
	public String socketBinding() {
		return this.socketBinding;
	}

	/**
	 * The socket binding that the acceptor will use to accept connections.
	 */
	@SuppressWarnings("unchecked")
	public RemoteAcceptor socketBinding(String value) {
		this.socketBinding = value;
		return (RemoteAcceptor) this;
	}

	/**
	 * Whether this acceptor is started.
	 */
	@ModelNodeBinding(detypedName = "started")
	public Boolean started() {
		return this.started;
	}

	/**
	 * Whether this acceptor is started.
	 */
	@SuppressWarnings("unchecked")
	public RemoteAcceptor started(Boolean value) {
		this.started = value;
		return (RemoteAcceptor) this;
	}
}
